@@ -54,6 +54,7 @@ import           Prelude hiding ((<>))
 import           Data.Monoid (Monoid(..))
 #endif
 
+import           Config
 import           Config.Schema.Spec
 import           Config.Schema.Types
 
@@ -130,14 +131,13 @@ valueDoc w =
   case w of
     TextSpec         -> pure "text"
     NumberSpec       -> pure "number"
-    AtomSpec a       -> pure ("`" <> txt a <> "`")
-    AnyAtomSpec      -> pure "atom"
+    AtomSpec         -> pure "atom"
     SectionsSpec l s -> sectionsDoc l s
     NamedSpec    l s -> emitDoc l (valuesDoc False s)
     CustomSpec l w'  -> (txt l                 <+>) <$> valuesDoc True w'
     ListSpec ws      -> ("list of"             <+>) <$> valuesDoc True ws
     AssocSpec ws     -> ("association list of" <+>) <$> valuesDoc True ws
-
+    ExactSpec v      -> pure ("`" <> prettyInline v <> "`")
 
 -- | A writer-like type. A mapping of section names and documentation
 -- lines is accumulated.
